``Products.GenericSetup``
=========================

.. image:: https://img.shields.io/pypi/v/Products.GenericSetup.svg
        :target: https://pypi.python.org/pypi/Products.GenericSetup/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/Products.GenericSetup.svg
        :target: https://pypi.org/project/Products.GenericSetup/
        :alt: Supported Python versions

.. image:: https://travis-ci.org/zopefoundation/Products.GenericSetup.svg?branch=master
        :target: https://travis-ci.org/zopefoundation/Products.GenericSetup

.. image:: https://coveralls.io/repos/github/zopefoundation/Products.GenericSetup/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/Products.GenericSetup?branch=master

.. image:: https://readthedocs.org/projects/productsgenericsetup/badge/?version=latest
        :target: https://productsgenericsetup.readthedocs.io/
        :alt: Documentation Status


This product provides a mini-framework for expressing the configured
state of a Zope Site as a set of filesystem artifacts.  These artifacts
consist of declarative XML files, which spell out the configuration
settings for each "tool" in the site , and supporting scripts / templates,
in their "canonical" filesystem representations.

See ``docs/index.rst`` for full documentation.  This documentation can
also be found online:  https://productsgenericsetup.readthedocs.io/
